@@ -34,9 +34,10 @@
 
 class KActionMenu;
 
+class QAction;
 class QFileInfo;
 class QMimeData;
-class QAction;
+class QTimer;
 
 class WebImageFetcher;
 class PlaylistItem;
@@ -372,6 +373,13 @@ public slots:
      */
     void slotRenameFile();
 
+    /**
+     * Select a track to play after being stopped.
+     *
+     * @see playNext()
+     */
+    void slotBeginPlayback();
+
     /**
      * Sets the cover of the selected items, pass in true if you want to load from the local system,
      * false if you want to load from the internet.
@@ -398,6 +406,12 @@ public slots:
      */
     virtual void slotReload();
 
+    /**
+     * Ensures the random sequence of playlist items is built. Ignored if we're
+     * not in random playback mode so it is safe to call in any mode.
+     */
+    void refillRandomList();
+
     /**
      * Tells the listview that the next time that it paints that the weighted
      * column widths must be recalculated.  If this is called without a column
@@ -425,6 +439,12 @@ protected:
      */
     void synchronizeItemsTo(const PlaylistItemList &itemList);
 
+    /**
+     * Completes the actions with the parent PlaylistCollection needed to
+     * actually start playing back the given PlaylistItem.
+     */
+    virtual void beginPlayingItem(PlaylistItem *itemToPlay);
+
     // the following are all reimplemented from base classes
 
     virtual bool eventFilter(QObject *watched, QEvent *e) override;
@@ -471,7 +491,7 @@ protected:
 
 protected slots:
     void slotPopulateBackMenu() const;
-    void slotPlayFromBackMenu(QAction *) const;
+    void slotPlayFromBackMenu(QAction *);
 
 signals:
 
@@ -672,6 +692,10 @@ private:
     bool m_widthsDirty                 = true;
     bool m_applySharedSettings         = true;
 
+    /// Used for random play and album random play
+    PlaylistItemList m_randomSequence;
+    QTimer          *m_refillDebounce;
+
     PlaylistSearch* m_search;
     bool m_searchEnabled = true;
 
